==> tuia-client-0.4.5-20180827.043125-11-sources.jar: cn/com/tuia/advert/constants/SystemConfigKeyConstant.java <==
package cn.com.tuia.advert.constants;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2017年03月15日 20:02
 * @descript:
 * @version: 1.0
 */
public interface SystemConfigKeyConstant {

    //单个用户key重复领取的周期时间
    String ADVERT_SINGLE_REPEAT_DAY = "advert.single.repeat.days";

    //广告轮流投放周期
    String ADVERT_TURNS_PUT_COUNT = "advert.turns.put.count";

    //广告轮流投放占比
    String ADVERT_TURNS_PUT_PROPORTION = "advert.turns.put.proportion";

    //开启全部特权媒体
    String APP_PRIVILEGE_ALL = "app.privilege.all";

    //oCPC启用的效果pv次数
    String OCPC_ENABLE_COUNT = "ocpc.enable.count";

    //oCPC最低转换出价(单位:元)
    String OCPC_CONVERT_MIN_PRICE = "ocpc.convert.min.price";

    //oCPC最低点击出价(单位:元)
    String OCPC_CLICK_MIN_PRICE = "ocpc.click.min.price";

    //广告定向包预算释放时间
    String ADVERT_PACKAGE_BUDGET_TIME_RELEASE = "advert.package.budget.time.release";

    //用户领取次数开启素材过滤
    String MATERIAL_FILTER_CONSUMER_COUNT = "material.filter.consumer.count";

    //cpc二次确认阈值价格
    String CPC_CONFIRM_THRESHOLD_PRICE = "cpc.confirm.threshold.price";

    //ocpc二次确认阈值价格
    String OCPC_CONFIRM_THRESHOLD_PRICE = "ocpc.confirm.threshold.price";

    //特殊代理商的OCPC最底价(单位:元)
    String SPECIAL_AGENT_OCPC_CONVERT_MIN_PRICE = "special.agent.ocpc.convert.min.price";

    //es集群ip,包含端口，例如：10.26.93.122:9300,10.24.24.138:9300,10.26.48.232:930
    String ELASTIC_SEARCH_CLUSTER_SERVER = "elasticsearch.cluster.server";

    //es集群名称
    String ELASTIC_SEARCH_CLUSTER_NAME = "elasticsearch.cluster.name";

    //重复曝光上限次数
    String MULTIPLE_EXPOSURE_LIMIT_COUNT = "multiple.exposure.limit.count";

    //推啊发送邮件的默认系统发件人信息配置
    String TUIA_MAIL_SYSTEM_SENDER = "tuia.mail.system.sender";

    //手机品牌
    String TUIA_PHONE_BRAND = "tuia.phone.brand";

    //某些特殊的广告位请求算法时，使用场景二的流量分配
    String TUIA_NEZHA_SOLTID_SCENE_TWO = "tuia.nezha.soltId.scene.two";

    //兑吧cpc对低价
    String DUIBA_CPC_FLOOR_PRICE = "duiba.cpc.floor.price";

    //兑吧cpc的折扣率
    String DUIBA_CPC_BID_RATE = "duiba.cpc.bid.rate";

    //某些特殊的广告位请求算法时，使用场景三的流量分配
    String TUIA_NEZHA_SOLTID_SCENE_THREE = "tuia.nezha.soltId.scene.three";

    //行业标签规则过滤的
    String TUIA_TRADE_TAG_RULE = "tuia.trade.tag.rule";

    //行业标签规则计算分值
    String TUIA_TRADE_TAG_RULE_RADIX = "tuia.trade.tag.rule.radix";
    
    // 兑吧未审核时，这些标签代表了兑吧不可投
    String DUIBA_DEFAULT_BANNED_NEWTAGNUM = "duiba.default.banned.newTagNum";
    
    // 广告位限流测试广告
    String TUIA_LIMIT_APPS_SLOT_ADVERT_IDS = "tuia.limit.apps.slot.advert.ids";

    //谢谢参与数
    String TUIA_THKS_PARTAKE_COUNT = "tuia.thks.partake.count";

    //流量分配速率
    String TUIA_FLOW_DISTRIBUTION_RATE = "tuia.flow.distribution.rate";

    //推啊测试的广告及对应的活动配置
    String TUIA_TEST_ADVERT_ACTIVITY = "tuia.test.advert.activity";

    /** 广告主调整日预算每次调整幅度，全局配置表读取的tuiakey **/
    String BUDGET_ADJUST_LINE_CONFIG_KEY = "tuia.advert.web.budget.per";
    
    // 单用户广告主发券上限设置
    String TUIA_ADVERTISER_LAUNCH_LIMIT = "tuia.advertiser.launch.limit";
    
    // 单用户广告主发券间隔
    String TUIA_ADVERTISER_LAUNCH_INTERVAL = "tuia.advertiser.launch.interval";
    
    // 福利流量占比缓存 
    String TUIA_ADVERT_WELFARE_FLOW_PERCENT = "tuia.advert.welfare.flow.percent";

    // 判断寡头广告条件 连续三天广告主单日消耗间隔
    String TUIA_GRADE_POINT_LIST ="tuia.grade.point.list";

    // 寡头广告每个间隔 对应的切量比
    String TUIA_GRADE_SCOPE_PROPORTION_LIST="tuia.grade.scope.proportion.list";

    // 判断寡头广告主条件  连续三天消耗占比
    String TUIA_ADVERTISER_CONSUMPTION_PROPORTION = "tuia.advertiser.consumption.proportion";

    // 判断寡头广告主条件 寡头广告连续三天计划都超过金额
    String TUIA_ADVERT_CONSUMPTION = "tuia.advert.consumption";

    //已选中的潜力广告行业
    String TUIA_POTENTIAL_TRADELIST = "tuia.potential.tradelist";

    //潜力广告主筛选条件 连续三天单天消耗范围
    String TUIA_ADVERTISER_CONSUMPTION_SCOPE = "tuia.advertiser.consumption.scope";

    //判断潜力广告主 连续三天广告主arup超过值
    String TUIA_ARUP_SCOPE = "tuia.arup.scope";

    //重点扶持的广告主id
    String TUIA_INTENSIVE_ADVERTISER_LIST ="tuia.intensive.advertiser.list";
    //  dmp测试开关
    String DPM_DATA_OPEN="tuia.dmp.switch";

    //  dmp测试广告
    String DPM_TEST_DATA="tuia.dmp.data";
}

==> tuia-client-0.4.9-20180920.122740-4-sources.jar: cn/com/tuia/advert/constants/SystemConfigKeyConstant.java <==
package cn.com.tuia.advert.constants;

/**
 * @author: <a href="http://www.panaihua.com">panaihua</a>
 * @date: 2017年03月15日 20:02
 * @descript:
 * @version: 1.0
 */
public interface SystemConfigKeyConstant {

    //单个用户key重复领取的周期时间
    String ADVERT_SINGLE_REPEAT_DAY = "advert.single.repeat.days";

    //广告轮流投放周期
    String ADVERT_TURNS_PUT_COUNT = "advert.turns.put.count";

    //广告轮流投放占比
    String ADVERT_TURNS_PUT_PROPORTION = "advert.turns.put.proportion";

    //开启全部特权媒体
    String APP_PRIVILEGE_ALL = "app.privilege.all";

    //oCPC启用的效果pv次数
    String OCPC_ENABLE_COUNT = "ocpc.enable.count";

    //oCPC最低转换出价(单位:元)
    String OCPC_CONVERT_MIN_PRICE = "ocpc.convert.min.price";

    //oCPC最低点击出价(单位:元)
    String OCPC_CLICK_MIN_PRICE = "ocpc.click.min.price";

    //广告定向包预算释放时间
    String ADVERT_PACKAGE_BUDGET_TIME_RELEASE = "advert.package.budget.time.release";

    //用户领取次数开启素材过滤
    String MATERIAL_FILTER_CONSUMER_COUNT = "material.filter.consumer.count";

    //cpc二次确认阈值价格
    String CPC_CONFIRM_THRESHOLD_PRICE = "cpc.confirm.threshold.price";

    //ocpc二次确认阈值价格
    String OCPC_CONFIRM_THRESHOLD_PRICE = "ocpc.confirm.threshold.price";

    //特殊代理商的OCPC最底价(单位:元)
    String SPECIAL_AGENT_OCPC_CONVERT_MIN_PRICE = "special.agent.ocpc.convert.min.price";

    //es集群ip,包含端口，例如：10.26.93.122:9300,10.24.24.138:9300,10.26.48.232:930
    String ELASTIC_SEARCH_CLUSTER_SERVER = "elasticsearch.cluster.server";

    //es集群名称
    String ELASTIC_SEARCH_CLUSTER_NAME = "elasticsearch.cluster.name";

    //重复曝光上限次数
    String MULTIPLE_EXPOSURE_LIMIT_COUNT = "multiple.exposure.limit.count";

    //推啊发送邮件的默认系统发件人信息配置
    String TUIA_MAIL_SYSTEM_SENDER = "tuia.mail.system.sender";

    //手机品牌
    String TUIA_PHONE_BRAND = "tuia.phone.brand";

    //某些特殊的广告位请求算法时，使用场景二的流量分配
    String TUIA_NEZHA_SOLTID_SCENE_TWO = "tuia.nezha.soltId.scene.two";

    //兑吧cpc对低价
    String DUIBA_CPC_FLOOR_PRICE = "duiba.cpc.floor.price";

    //兑吧cpc的折扣率
    String DUIBA_CPC_BID_RATE = "duiba.cpc.bid.rate";

    //某些特殊的广告位请求算法时，使用场景三的流量分配
    String TUIA_NEZHA_SOLTID_SCENE_THREE = "tuia.nezha.soltId.scene.three";

    //行业标签规则过滤的
    String TUIA_TRADE_TAG_RULE = "tuia.trade.tag.rule";

    //行业标签规则计算分值
    String TUIA_TRADE_TAG_RULE_RADIX = "tuia.trade.tag.rule.radix";
    
    // 兑吧未审核时，这些标签代表了兑吧不可投
    String DUIBA_DEFAULT_BANNED_NEWTAGNUM = "duiba.default.banned.newTagNum";
    
    // 广告位限流测试广告
    String TUIA_LIMIT_APPS_SLOT_ADVERT_IDS = "tuia.limit.apps.slot.advert.ids";

    //谢谢参与数
    String TUIA_THKS_PARTAKE_COUNT = "tuia.thks.partake.count";

    //流量分配速率
    String TUIA_FLOW_DISTRIBUTION_RATE = "tuia.flow.distribution.rate";

    //推啊测试的广告及对应的活动配置
    String TUIA_TEST_ADVERT_ACTIVITY = "tuia.test.advert.activity";

    /** 广告主调整日预算每次调整幅度，全局配置表读取的tuiakey **/
    String BUDGET_ADJUST_LINE_CONFIG_KEY = "tuia.advert.web.budget.per";
    
    // 单用户广告主发券上限设置
    String TUIA_ADVERTISER_LAUNCH_LIMIT = "tuia.advertiser.launch.limit";
    
    // 单用户广告主发券间隔
    String TUIA_ADVERTISER_LAUNCH_INTERVAL = "tuia.advertiser.launch.interval";
    
    // 福利流量占比缓存 
    String TUIA_ADVERT_WELFARE_FLOW_PERCENT = "tuia.advert.welfare.flow.percent";

    // 判断寡头广告条件 连续三天广告主单日消耗间隔
    String TUIA_GRADE_POINT_LIST ="tuia.grade.point.list";

    // 寡头广告每个间隔 对应的切量比
    String TUIA_GRADE_SCOPE_PROPORTION_LIST="tuia.grade.scope.proportion.list";

    // 判断寡头广告主条件  连续三天消耗占比
    String TUIA_ADVERTISER_CONSUMPTION_PROPORTION = "tuia.advertiser.consumption.proportion";

    // 判断寡头广告主条件 寡头广告连续三天计划都超过金额
    String TUIA_ADVERT_CONSUMPTION = "tuia.advert.consumption";

    //已选中的潜力广告行业
    String TUIA_POTENTIAL_TRADELIST = "tuia.potential.tradelist";

    //潜力广告主筛选条件 连续三天单天消耗范围
    String TUIA_ADVERTISER_CONSUMPTION_SCOPE = "tuia.advertiser.consumption.scope";

    //判断潜力广告主 连续三天广告主arup超过值
    String TUIA_ARUP_SCOPE = "tuia.arup.scope";

    //重点扶持的广告主id
    String TUIA_INTENSIVE_ADVERTISER_LIST ="tuia.intensive.advertiser.list";
    //  dmp测试开关
    String DPM_DATA_OPEN = "tuia.dmp.switch";

    //  dmp测试广告
    String DPM_TEST_DATA = "tuia.dmp.data";

    //风控反作弊流量切量比例
    String RISK_CHEAT_PERCENT = "risk.cheat.percent";

    //风控反作弊流量测试广告
    String RISK_CHEAT_ADVERT = "risk.cheat.advert";

    //广告在新媒体发券上限
    String TUIA_NEW_APP_LAUNCH_MAX = "tuia.new.app.launch.max";

    //广告在新媒体计费点击上限
    String TUIA_NEW_APP_EFFCLICK_MAX = "tuia.new.app.effclick.max";
}
